@@ -2,12 +2,12 @@
 from __future__ import absolute_import
 
 import base64
+import datetime
 import hashlib
 import hmac
 import re
 from time import gmtime, strftime
 
-import datetime
 from requests import request
 from requests.exceptions import HTTPError
 
@@ -79,10 +79,7 @@ def remove_empty(d):
     Return:
         dict
     """
-    for key in set(d.keys()):
-        if not d[key]:
-            del d[key]
-    return d
+    return {k: v for k, v in d.items() if v}
 
 
 def remove_namespace(xml):
@@ -114,7 +111,7 @@ class DataWrapper(object):
         self.original = data
         if 'content-md5' in header:
             hash_ = calc_md5(self.original)
-            if header['content-md5'] != hash_:
+            if header['content-md5'].encode() != hash_:
                 raise MWSError("Wrong Contentlength, maybe amazon error...")
 
     @property
@@ -212,10 +209,14 @@ class MWS(object):
             data = response.content
             # I do not check the headers to decide which content structure to server simply because sometimes
             # Amazon's MWS API returns XML error responses with "text/plain" as the Content-Type.
+            rootkey = kwargs.get('rootkey', extra_data.get("Action") + "Result")
             try:
-                parsed_response = DictWrapper(data, extra_data.get("Action") + "Result")
-            except TypeError:  # raised when using Python 3 and trying to remove_namespace()
-                parsed_response = DictWrapper(response.text, extra_data.get("Action") + "Result")
+                try:
+                    parsed_response = DictWrapper(data, rootkey)
+                except TypeError:  # raised when using Python 3 and trying to remove_namespace()
+                    # When we got CSV as result, we will got error on this
+                    parsed_response = DictWrapper(response.text, rootkey)
+
             except XMLError:
                 parsed_response = DataWrapper(data, response.headers)
 
@@ -336,7 +337,7 @@ class Feeds(MWS):
 
     def get_feed_submission_result(self, feedid):
         data = dict(Action='GetFeedSubmissionResult', FeedSubmissionId=feedid)
-        return self.make_request(data)
+        return self.make_request(data, rootkey='Message')
 
 
 class Reports(MWS):
